@@ -4,7 +4,7 @@
 
 =head2 SYNOPSIS 
 
- PERL PROGRAM NAME: L_SUV0.81.4.pl 
+ PERL PROGRAM NAME: L_SUV0.82.1.pl 
  AUTHOR: 	Juan Lorenzo
  DATE: 		June 22 2017 
 
@@ -55,6 +55,8 @@
  
  V0.80.00 September 19, 2022 ready for initial uploading to the CPAN
  
+ V0.82.1 April 2023, ready for automatic installation and Earthscope summer program 
+ 
 =cut
 
 =head2 USE
@@ -659,7 +661,7 @@ print join("\n", $top_menu_bar->bind($class) ), "\n";
 	);
 
 	( $main_href->{_file_menubutton} )->separator;
-	$main_href->{_SaveAs_menubutton} = ( $main_href->{_file_menubutton} )->command(
+	$main_href->{_Delete_menubutton} = ( $main_href->{_file_menubutton} )->command(
 		-label     => @$alias_FileDialog_button_label[2],
 		-underline => 0,
 		-command   => [ \&_L_SU, 'FileDialog_button', \$File_option[2] ],
